@@ -3,8 +3,9 @@ from .generate_typed_dict import GenerateTypedDict
 from .schema_mapping import prim_to_type, logical_to_python_type
 from fastavro.schema import load_schema, expand_schema, parse_schema
 import ast
+import astunparse
+import black
 import json
-import astor
 
 
 def is_nullable(field):
@@ -140,7 +141,9 @@ def types_for_schema(schema):
 
     body.append(main_type.tree)
     imports = sorted(list(set(imports)))
-    return "".join(imports) + "\n\n" + astor.to_source(_dedupe_ast(tree))
+    generated_code = "".join(imports) + astunparse.unparse(_dedupe_ast(tree))
+    formatted_code = black.format_str(generated_code, mode=black.FileMode())
+    return formatted_code
 
 
 def typed_dict_from_schema_string(schema_string):
